@@ -3,7 +3,6 @@
 #' \pkg{Markdown} is a plain-text formatting syntax that can be converted to
 #' XHTML or other formats. This package provides wrapper functions (mainly
 #' [mark()]) based on the \pkg{commonmark} package.
-#' @name markdown
-#' @docType package
-#' @keywords package
-NULL
+'_PACKAGE'
+
+.env = new.env(parent = emptyenv())
